<?php
/*
 * Register Theme Customizer
 */

add_action('customize_register', 'cocobasic_customize_register');
add_action('customize_controls_enqueue_scripts', 'cocobasic_customize_control_js');

function cocobasic_customize_register($wp_customize) {

    function cocobasic_clean_html($value) {
        $allowed_html_array = cocobasic_allowed_html();
        $value = wp_kses($value, $allowed_html_array);
        return $value;
    }

    function cocobasic_sanitize_select($input, $setting) {
        $input = sanitize_key($input);
        $choices = $setting->manager->get_control($setting->id)->choices;
        return ( array_key_exists($input, $choices) ? $input : $setting->default );
    }

    class Cocobasic_Customize_Textarea_Control extends WP_Customize_Control {

        public $type = 'textarea';

        public function render_content() {
            ?>
            <label>
                <span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
                <textarea rows="5"  <?php $this->link(); ?>><?php echo esc_textarea($this->value()); ?></textarea>
            </label>
            <?php
        }

    }

    //------------------------- MENU SECTION ---------------------------------------------

    $wp_customize->add_section('cocobasic_menu_settings', array(
        'title' => esc_html__('Menu Text', 'romea-wp'),
        'priority' => 30
    ));

    $wp_customize->add_setting('cocobasic_custom_menu_text', array(
        'default' => '',
        'sanitize_callback' => 'cocobasic_clean_html'
    ));
    $wp_customize->add_control('cocobasic_custom_menu_text', array(
        'label' => esc_html__('Menu Text:', 'romea-wp'),
        'section' => 'cocobasic_menu_settings',
        'settings' => 'cocobasic_custom_menu_text'
    ));

    $wp_customize->add_setting('cocobasic_select_menu_text', array(
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'cocobasic_sanitize_select',
        'default' => '',
    ));


    $wp_customize->add_control('cocobasic_select_menu_text', array(
        'type' => 'select',
        'section' => 'cocobasic_menu_settings',
        'label' => esc_html__('Menu Right Content:', 'romea-wp'),
        'description' => esc_html__('select one of Elementor templates', 'romea-wp'),
        'choices' => cocobasic_create_elementor_library_list()
    ));

    //------------------------- END MENU SECTION ---------------------------------------------
    //
    //    
    //            
    //----------------------------- IMAGE SECTION  ---------------------------------------------

    $wp_customize->add_section('cocobasic_image_section', array(
        'title' => esc_html__('Images Section', 'romea-wp'),
        'priority' => 33
    ));

    $wp_customize->add_setting('cocobasic_preloader', array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'cocobasic_preloader', array(
        'label' => esc_html__('Preloader Gif', 'romea-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'cocobasic_preloader'
    )));


    $wp_customize->add_setting('cocobasic_preloader_width', array(
        'default' => "50px",
        'sanitize_callback' => 'cocobasic_clean_html'
    ));
    $wp_customize->add_control('cocobasic_preloader_width', array(
        'label' => esc_html__('Preloader Width:', 'romea-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'cocobasic_preloader_width'
    ));


    $wp_customize->add_setting('cocobasic_header_logo', array(
        'default' => get_template_directory_uri() . '/images/logo.png',
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'cocobasic_header_logo', array(
        'label' => esc_html__('Header Logo', 'romea-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'cocobasic_header_logo'
    )));


    $wp_customize->add_setting('cocobasic_logo_width', array(
        'default' => "60px",
        'sanitize_callback' => 'cocobasic_clean_html'
    ));
    $wp_customize->add_control('cocobasic_logo_width', array(
        'label' => esc_html__('Logo Width:', 'romea-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'cocobasic_logo_width'
    ));


    $wp_customize->add_setting('cocobasic_logo_phone_width', array(
        'default' => "40px",
        'sanitize_callback' => 'cocobasic_clean_html'
    ));
    $wp_customize->add_control('cocobasic_logo_phone_width', array(
        'label' => esc_html__('Logo Width (on small resolutions):', 'romea-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'cocobasic_logo_phone_width'
    ));

    //----------------------------- END IMAGE SECTION  ---------------------------------------------
    //
    //
    //
    //---------------------------------- COLORS SECTION --------------------

    function cocobasic_get_color_scheme_choices() {
        $color_schemes = cocobasic_get_color_schemes();
        $color_scheme_control_options = array();

        foreach ($color_schemes as $color_scheme => $value) {
            $color_scheme_control_options[$color_scheme] = $value['label'];
        }

        return $color_scheme_control_options;
    }

    function cocobasic_get_color_schemes() {
        return apply_filters('cocobasic_color_schemes', array(
            'demo1' => array(
                'label' => esc_html__('Demo 1', 'romea-wp'),
                'colors' => array(
                    '#ffffff',
                    '#ebebeb',
                    '#000000',
                    '#96dfff',
                    '#000000',
                    '#ffffff',
                    '#ffffff',
                    '#bbbbbb',
                    '#000000',
                    '#000000',
                    '#ffffff',
                    '#e2e2e2',
                ),
            ),
            'demo2' => array(
                'label' => esc_html__('Demo 2', 'romea-wp'),
                'colors' => array(
                    '#ffffff',
                    '#ffffff',
                    '#93405e',
                    '#f56184',
                    '#e74b70',
                    '#ffffff',
                    '#ffffff',
                    '#77324b',
                    '#e74b70',
                    '#e74b70',
                    '#ffebec',
                    '#ffdbdd',
                ),
            )
        ));
    }

    $wp_customize->add_setting('cocobasic_color_scheme_selector', array(
        'default' => 'demo1',
        'sanitize_callback' => 'cocobasic_clean_html',
        'transport' => 'postMessage',
    ));

    $wp_customize->add_control('cocobasic_color_scheme_selector', array(
        'label' => esc_html__('Base Color Scheme', 'romea-wp'),
        'section' => 'colors',
        'type' => 'select',
        'choices' => cocobasic_get_color_scheme_choices(),
        'priority' => 1,
    ));

    $wp_customize->add_setting('cocobasic_preloader_background_color', array(
        'default' => '#ffffff',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_preloader_background_color', array(
        'label' => esc_html__('Preloader Background Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_preloader_background_color'
    )));


    $wp_customize->add_setting('cocobasic_body_background_color', array(
        'default' => '#ebebeb',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_body_background_color', array(
        'label' => esc_html__('Body Background Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_body_background_color'
    )));


    $wp_customize->add_setting('cocobasic_body_color', array(
        'default' => '#000000',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_body_color', array(
        'label' => esc_html__('Body Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_body_color'
    )));


    $wp_customize->add_setting('cocobasic_link_color', array(
        'default' => '#96dfff',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_link_color', array(
        'label' => esc_html__('Link Underline Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_link_color'
    )));


    $wp_customize->add_setting('cocobasic_burger_menu_background', array(
        'default' => '#000000',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_burger_menu_background', array(
        'label' => esc_html__('Menu Lines (Burger) Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_burger_menu_background'
    )));


    $wp_customize->add_setting('cocobasic_burger_mobile_menu_background', array(
        'default' => '#ffffff',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_burger_mobile_menu_background', array(
        'label' => esc_html__('Menu Lines (Burger) Color (small resolutions)', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_burger_mobile_menu_background'
    )));


    $wp_customize->add_setting('cocobasic_menu_color', array(
        'default' => '#ffffff',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_menu_color', array(
        'label' => esc_html__('Menu Items Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_menu_color'
    )));


    $wp_customize->add_setting('cocobasic_submenu_color', array(
        'default' => '#bbbbbb',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_submenu_color', array(
        'label' => esc_html__('Sub Menu Items Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_submenu_color'
    )));


    $wp_customize->add_setting('cocobasic_menu_background_color', array(
        'default' => '#000000',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_menu_background_color', array(
        'label' => esc_html__('Menu Background Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_menu_background_color'
    )));


    $wp_customize->add_setting('cocobasic_dark_section_background_color', array(
        'default' => '#000000',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_dark_section_background_color', array(
        'label' => esc_html__('Dark Section Background Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_dark_section_background_color'
    )));


    $wp_customize->add_setting('cocobasic_light_section_background_color', array(
        'default' => '#ffffff',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_light_section_background_color', array(
        'label' => esc_html__('Light Section Background Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_light_section_background_color'
    )));


    $wp_customize->add_setting('cocobasic_comments_background_color', array(
        'default' => '#e2e2e2',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cocobasic_comments_background_color', array(
        'label' => esc_html__('Comments Background Color', 'romea-wp'),
        'section' => 'colors',
        'settings' => 'cocobasic_comments_background_color'
    )));


    //---------------------------------------- END COLORS SECTION ------------------------------------------------------
    //
    //
    //
    //---------------------------------- FOOTER SECTION --------------------

    $wp_customize->add_section('cocobasic_footer_section', array(
        'title' => esc_html__('Footer', 'romea-wp'),
        'priority' => 99
    ));

    $wp_customize->add_setting('cocobasic_select_footer', array(
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'cocobasic_sanitize_select',
        'default' => '',
    ));


    $wp_customize->add_control('cocobasic_select_footer', array(
        'type' => 'select',
        'section' => 'cocobasic_footer_section',
        'label' => esc_html__('Custom footer layout', 'romea-wp'),
        'description' => esc_html__('select one of Elementor templates', 'romea-wp'),
        'choices' => cocobasic_create_elementor_library_list()
    ));


    //---------------------------------------- END FOOTER SECTION ------------------------------------------------------
    //
    //
    //
    //
    //--------------------------------------------------------------------------
    $wp_customize->get_setting('cocobasic_preloader_background_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_body_background_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_body_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_link_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_burger_menu_background')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_burger_mobile_menu_background')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_menu_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_submenu_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_menu_background_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_dark_section_background_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_light_section_background_color')->transport = 'postMessage';
    $wp_customize->get_setting('cocobasic_comments_background_color')->transport = 'postMessage';

    //--------------------------------------------------------------------------
    /*
     * If preview mode is active, hook JavaScript to preview changes
     */
    if ($wp_customize->is_preview() && !is_admin()) {
        add_action('customize_preview_init', 'cocobasic_customize_preview_js');
    }
}

/**
 * Bind Theme Customizer JavaScript
 */
function cocobasic_customize_preview_js() {
    wp_enqueue_script('cocobasic-customizer', get_template_directory_uri() . '/admin/js/custom-admin.js', array('customize-preview'), '', true);
}

function cocobasic_customize_control_js() {
    wp_enqueue_script('color-scheme-control', get_template_directory_uri() . '/admin/js/color-scheme-control.js', array('customize-controls'), '', true);
    wp_localize_script('color-scheme-control', 'colorScheme', cocobasic_get_color_schemes());
}

/*
 * Generate CSS Styles
 */

class Cocobasic_Css {

    public static function cocobasic_theme_customized_style() {
        echo '<style id="cocobasic-customizer-style" type="text/css">' .
        cocobasic_generate_css('body .doc-loader', 'background-color', 'cocobasic_preloader_background_color') .
        cocobasic_generate_css('html body, body .header-left-part, body .header-logo.add-background:after', 'background-color', 'cocobasic_body_background_color') .
        cocobasic_generate_css('html body, body h1, body h2, body h3, body h4, body h5, body h6, body .site-content a, body [data-elementor-type="wp-page"] a, body footer .elementor-text-editor a, body .input-default-text, body .wpcf7-form input[type=text], body .wpcf7-form input[type=email], body .wpcf7-form textarea, body span.wpcf7-not-valid-tip, body .wpcf7 form.invalid .wpcf7-response-output, body .wpcf7 form.unaccepted .wpcf7-response-output, body .search-field, body footer, body footer a, body #commentform #email, body #commentform #author, body #commentform #comment, body .form-submit input[type=submit], body .more-posts, body .no-more-posts, body .more-posts-loading', 'color', 'cocobasic_body_color') .
        cocobasic_generate_css('body .wpcf7-form .contact-submit-holder:after, body .search-field:focus, body .form-submit:after, body .more-posts:before, body .no-more-posts:before, body .more-posts-loading:before', 'border-color', 'cocobasic_body_color') .
        cocobasic_generate_css('body.single .nav-links:before, body blockquote', 'background-color', 'cocobasic_body_color') .
        cocobasic_generate_css('body .search-field::-webkit-input-placeholder', 'color', 'cocobasic_body_color') .
        cocobasic_generate_css('body .search-field:-ms-input-placeholder', 'color', 'cocobasic_body_color') .
        cocobasic_generate_css('body .search-field::placeholder', 'color', 'cocobasic_body_color') .
        cocobasic_generate_css('body h1 a:hover, body h2 a:hover, body h3 a:hover, body h4 a:hover, body h5 a:hover, body h6 a:hover, body .logged-in-as, body .wp-link-pages > a:hover', 'color', 'cocobasic_link_color') .
        cocobasic_generate_css('body .wpcf7 form.invalid .wpcf7-response-output, body .wpcf7 form.unaccepted .wpcf7-response-output', 'border-color', 'cocobasic_link_color') .
        cocobasic_generate_css('body .site-content a:after, body [data-elementor-type="wp-page"] a:after, body footer .elementor-text-editor a:after, body .sm-clean > li > a:after, body span.wpcf7-not-valid-tip, body .wpcf7 form.invalid .wpcf7-response-output, body .wpcf7 form.unaccepted .wpcf7-response-output, body [data-elementor-type="wp-page"] a.coco-button-underline:after, body .wp-link-pages > span, body .widget a:after', 'background-color', 'cocobasic_link_color') .
        cocobasic_generate_css('body .sm-clean a, body .sm-clean a:hover, body .sm-clean a:focus, body .sm-clean a:active, body .custom-menu-title', 'color', 'cocobasic_menu_color') .
        cocobasic_generate_css('body .sm-clean a span.sub-arrow, body .sm-clean .sub-menu li a, body .sm-clean .children li a', 'color', 'cocobasic_submenu_color') .
        cocobasic_generate_css('body .header-full-menu, body .header-right-part-holder', 'background-color', 'cocobasic_menu_background_color') .
        cocobasic_generate_css('body #toggle div', 'background-color', 'cocobasic_burger_menu_background') .
        cocobasic_generate_css('body.small-menu #toggle div, body.cocobasic-open-menu #toggle div, body.cocobasic-open-menu-done #toggle div', 'background-color', 'cocobasic_burger_mobile_menu_background') .
        cocobasic_generate_css('body .cocobasic-dark-section, body .skill-fill-mask, body.single.single-portfolio .content-holder, body .archive-title, html body .tags-holder a, body .img-caption, body .alignfull > figcaption, body .alignfull > .wp-caption-text, body.search .nav-links .current, body.archive .nav-links .current', 'background-color', 'cocobasic_dark_section_background_color') .
        cocobasic_generate_css('html body .tags-holder a', 'border-color', 'cocobasic_dark_section_background_color') .
        cocobasic_generate_css('body .tags-holder a:hover, body.search .nav-links a, body.archive .nav-links a, body.search .nav-links a:hover, body.archive .nav-links a:hover', 'color', 'cocobasic_dark_section_background_color') .
        cocobasic_generate_css('body .cocobasic-light-section, body .blog-item-holder .entry-holder, body.page-template-default .content-holder, body.single .content-holder, body.attachment .content-holder, body.error404 .content-holder, body .wp-block-columns.alignfull, body .alignfull:not(.has-background) .wp-block-columns', 'background-color', 'cocobasic_light_section_background_color') .
        cocobasic_generate_css('body #comments, body.archive .content-holder, body.search .content-holder', 'background-color', 'cocobasic_comments_background_color') .
        cocobasic_generate_additional_css() .
        '</style>';
    }

}

/*
 * Generate CSS Class - Helper Method
 */

function cocobasic_generate_css($selector, $style, $mod_name, $prefix = '', $postfix = '') {
    $return = '';
    $mod = get_option($mod_name);
    if (!empty($mod)) {
        $return = sprintf('%s { %s:%s; }', $selector, $style, $prefix . $mod . $postfix);
    }
    return $return;
}

function cocobasic_generate_additional_css() {
    $allowed_html_array = cocobasic_allowed_html();
    $return = '';

    if (get_theme_mod('cocobasic_preloader_width') != ''):
        $return .= 'body .doc-loader img{width: ' . get_theme_mod('cocobasic_preloader_width') . ';}';
    endif;

    if (get_theme_mod('cocobasic_logo_width') != ''):
        $return .= 'body .header-logo img{width: ' . get_theme_mod('cocobasic_logo_width') . ';}';
        $return .= 'body .header-logo{right: -' . get_theme_mod('cocobasic_logo_width') . ';}';
    endif;

    if (get_theme_mod('cocobasic_logo_phone_width') != ''):
        $return .= '@media screen and (max-width: 1365px){body .header-logo img {width: ' . get_theme_mod('cocobasic_logo_phone_width') . ' !important;}}';
    endif;

    if (get_theme_mod('cocobasic_color_scheme_selector') === 'demo2'):
        $return .= 'body.page-template-default .content-holder, body.single .content-holder, body.attachment .content-holder, body.error404 .content-holder, body .blog-item-holder .entry-holder, body.archive .content-holder, body.search .content-holder {border-radius: 25px;}';
        $return .= 'body.archive .content-holder, body.search .content-holder {overflow: hidden;}';
        $return .= 'body .blog-item-holder img {border-radius: 22px;}';
        $return .= 'body.single .attachment-post-thumbnail, body .elementor-widget-coco-imageslider img {border-radius: 20px;}';
        $return .= 'body blockquote {border-radius: 15px;}';
        $return .= 'body .owl-theme .owl-dots .owl-dot span, body.search .nav-links .current, body.archive .nav-links .current {border-radius: 3px;}';
    endif;

    $return = wp_strip_all_tags($return);
    return $return;
}

function cocobasic_create_elementor_library_list() {
    $listArray = ['' => ''];
    global $post;

    $elementorLoop = new WP_Query(array(
        'post_type' => 'elementor_library',
        'post_status' => 'publish',
        'posts_per_page' => '-1'
    ));

    while ($elementorLoop->have_posts()) : $elementorLoop->the_post();
        $listArray += [ $post->ID => $post->post_name];
    endwhile;

    wp_reset_postdata();
    return $listArray;
}
?>