<?php

namespace CocoBasicElements\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\utils;

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

class coco_carouseltestimonial extends Widget_Base {

    public function get_name() {
        return 'coco-carouseltestimonial';
    }

    public function get_title() {
        return esc_attr__('Carousel Testimonial', 'cocobasic-elementor');
    }

    public function get_icon() {
        return 'fa fa-th';
    }

    public function get_categories() {
        return array('coco-element');
    }

    protected function register_controls() {

        $this->start_controls_section(
                'section_process_1', [
            'label' => esc_attr__('Content', 'cocobasic-elementor'),
                ]
        );

        $this->add_control(
                'quote_img', [
            'label' => esc_attr__('Quote Image', 'cocobasic-elementor'),
            'type' => Controls_Manager::MEDIA,
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ],
            'label_block' => true,
                ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
                'title', [
            'label' => esc_attr__('Slide Name', 'cocobasic-elementor'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_attr__('Slide Name', 'cocobasic-elementor'),
                ]
        );

        $repeater->add_control(
                'img', [
            'label' => esc_attr__('Image', 'cocobasic-elementor'),
            'type' => Controls_Manager::MEDIA,
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ],
            'label_block' => true,
                ]
        );

        $repeater->add_control(
                'url', [
            'label' => esc_attr__('Image Link (optional)', 'cocobasic-elementor'),
            'type' => Controls_Manager::URL,
            'label_block' => true,
            'placeholder' => esc_html__('http://your-link.com', 'cocobasic-elementor'),
                ]
        );

        $repeater->add_control(
                'name', [
            'label' => esc_attr__('Name', 'cocobasic-elementor'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => '',
                ]
        );

        $repeater->add_control(
                'position', [
            'label' => esc_attr__('Position', 'cocobasic-elementor'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => '',
                ]
        );

        $repeater->add_control(
                'testimonial_text', [
            'label' => esc_attr__('Testimonial Text', 'cocobasic-elementor'),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => '',
                ]
        );

        $this->add_control(
                'items', [
            'type' => Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'prevent_empty' => false,
            'default' => [
                [
                    'title' => esc_attr__('Content', 'cocobasic-elementor'),
                ]
            ],
            'title_field' => '{{{ title }}}',
                ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
                'section_process_2', [
            'label' => esc_attr__('Settings', 'cocobasic-elementor'),
                ]
        );


        $this->add_control(
                'name', [
            'label' => esc_attr__('Unique Carousel Name', 'cocobasic-elementor'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_attr__('Testimonial-1', 'cocobasic-elementor'),
                ]
        );

        $this->add_control(
                'speed', [
            'label' => esc_attr__('Speed (ms)', 'cocobasic-elementor'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_attr__('2000', 'cocobasic-elementor'),
                ]
        );

        $this->add_control(
                'auto_start', [
            'label' => esc_attr__('Auto Start', 'cocobasic-elementor'),
            'type' => Controls_Manager::SELECT,
            'label_block' => true,
            'options' => [
                'true' => esc_attr__('True', 'cocobasic-elementor'),
                'false' => esc_attr__('Fasle', 'cocobasic-elementor'),
            ],
            'default' => 'true',
                ]
        );
        
        $this->end_controls_section();


        $this->start_controls_section(
                'section_general', [
            'label' => esc_attr__('General', 'cocobasic-elementor'),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'scrollbar_color', [
            'label' => esc_attr__('Scrollbar Color', 'cocobasic-elementor'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .swiper-scrollbar' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'scrollbar_drag_color', [
            'label' => esc_attr__('Scrollbar Drag Color', 'cocobasic-elementor'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .swiper-scrollbar-drag' => 'background-color: {{VALUE}};',
            ],
                ]
        );
        
        $this->add_control(
                'scrollbar_border_radius', [
            'label' => esc_attr__('Scrollbar Drag Border Radius', 'cocobasic-elementor'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%'],
            'selectors' => [
                '{{WRAPPER}} .swiper-scrollbar-drag' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'testimonial_text_color', [
            'label' => esc_attr__('Testimonial Text Color', 'cocobasic-elementor'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .swiper-slide-testimonial-text' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'testimonial_text_typography',
            'label' => esc_attr__('Testimonial Text Typography', 'cocobasic-elementor'),
            'selector' => '{{WRAPPER}} .swiper-slide-testimonial-text',
                ]
        );

        $this->add_control(
                'testimonial_name_color', [
            'label' => esc_attr__('Testimonial Name Color', 'cocobasic-elementor'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .swiper-slide-name' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'testimonial_name_typography',
            'label' => esc_attr__('Tstimonial Name Typography', 'cocobasic-elementor'),
            'selector' => '{{WRAPPER}} .swiper-slide-name',
                ]
        );

        $this->add_control(
                'testimonial_position_color', [
            'label' => esc_attr__('Testimonial Position Color', 'cocobasic-elementor'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .swiper-slide-position' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'testimonial_position_typography',
            'label' => esc_attr__('Tstimonial Position Typography', 'cocobasic-elementor'),
            'selector' => '{{WRAPPER}} .swiper-slide-position',
                ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings();
        require dirname(__FILE__) . '/view.php';
    }

    private function content($content) {
        $quoteImg = $this->get_settings();
        $quoteImg = wp_get_attachment_image($quoteImg["quote_img"]["id"]);
        $out = '';

        foreach ($content as $item) {
            $img = $item['img']['id'] ? wp_get_attachment_image($item['img']['id'], '', '', ["class" => "testimonial-slide-img"]) : '';
            $name = $item['name'];
            $position = $item['position'];
            $text = $item['testimonial_text'];
            $url = $item['url']['url'];
            $ext = $item['url']['is_external'];
            $nofollow = $item['url']['nofollow'];
            $url = ( isset($url) && $url ) ? 'href=' . esc_url($url) . '' : '';
            $ext = ( isset($ext) && $ext ) ? 'target= _blank' : '';
            $nofollow = ( isset($url) && $url ) ? 'rel=nofollow' : '';
            $link = $url . ' ' . $ext . ' ' . $nofollow;


            if ($url != ''):
                $out .= '<div class="swiper-slide">';
                $out .= '<div class="swiper-slide-quote-image">' . $quoteImg . '</div>';
                $out .= '<div class="swiper-slide-testimonial-text">' . $text . '</div>';
                if ($img !== ''):
                    $out .= '<div class="swiper-slide-testimonial-img-holder"><a ' . $link . '>' . $img . '</a></div>';
                endif;
                if ($name !== ''):
                    $out .= '<p class="swiper-slide-name"><a ' . $link . '>' . $name . '</a></p>';
                endif;
                if ($position !== ''):
                    $out .= '<p class="swiper-slide-position">' . $position . '</p>';
                endif;
                $out .= '</div>';
            else:
                $out .= '<div class="swiper-slide">';
                $out .= '<div class="swiper-slide-quote-image">' . $quoteImg . '</div>';
                $out .= '<div class="swiper-slide-testimonial-text">' . $text . '</div>';
                if ($img !== ''):
                    $out .= '<div class="swiper-slide-testimonial-img-holder">' . $img . '</div>';
                endif;
                if ($name !== ''):
                    $out .= '<p class="swiper-slide-name">' . $name . '</p>';
                endif;
                if ($position !== ''):
                    $out .= '<p class="swiper-slide-position">' . $position . '</p>';
                endif;
                $out .= '</div>';
            endif;
        }

        return $out;
    }

}

$widgets_manager->register(new \CocoBasicElements\Widgets\coco_carouseltestimonial());
